@@ -2,16 +2,18 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakti",
-    "Send email" : "Pošalji e-poštu",
-    "Download" : "Preuzmi",
     "Rename" : "Preimenuj",
+    "Send email" : "Pošalji e-poštu",
     "Delete" : "Obriši",
+    "Download" : "Preuzmi",
     "can edit" : "mogu mijenjati",
+    "Add" : "Dodaj",
     "First name" : "Ime",
     "Last name" : "Prezime",
     "Password protection" : "Password protection",
     "Save" : "Spremi",
     "Description" : "Opis",
+    "Settings" : "Settings",
     "Cancel" : "Otkaži",
     "Invalid image" : "Nevažeća datoteka",
     "Name" : "Ime",
@@ -28,7 +30,6 @@ OC.L10N.register(
     "Member" : "Član",
     "Admin" : "Administrator",
     "Owner" : "Vlasnik",
-    "Users" : "Korisnici",
     "Additional names" : "Dodatna imena",
     "Nickname" : "Nadimak",
     "Notes" : "Notes",
