@@ -6,12 +6,13 @@ OC.L10N.register(
     "Contacts" : "Contactes",
     "Loading …" : "Cargament…",
     "General settings" : "Paramètres generals",
-    "Send email" : "Enviar email",
-    "Download" : "Telecargar",
     "Rename" : "Renomenar",
+    "Send email" : "Enviar email",
     "Delete" : "Suprimir",
+    "Download" : "Telecargar",
     "Copy link" : "Copiar lo ligam",
     "can edit" : "pòt modificar",
+    "Add" : "Ajustar",
     "First name" : "Prenom",
     "Last name" : "Nom",
     "Display name" : "Nom afichat",
@@ -40,7 +41,6 @@ OC.L10N.register(
     "Admin" : "Admin",
     "Owner" : "Owner",
     "Visibility" : "Visibilitat",
-    "Users" : "Utilizaires",
     "Additional names" : "Noms suplementaris",
     "Nickname" : "Escais",
     "Notes" : "Nòtas",
