@@ -31,6 +31,7 @@ OC.L10N.register(
     "Contact groups" : "联系人群组",
     "Create a new contact group" : "创建联系人群组",
     "Contact group name" : "联系人群组名称",
+    "Create a new team" : "创建新团队",
     "Show all groups" : "显示所有小组",
     "Collapse groups" : "折叠小组",
     "This group already exists" : "该群组已存在",
@@ -47,7 +48,6 @@ OC.L10N.register(
     "Renaming of address book was not successful." : "通讯录重命名不成功",
     "_%n contact_::_%n contacts_" : ["%n 位联系人"],
     "_%n group_::_%n groups_" : ["%n 个群组"],
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
     "Share with users or groups" : "与用户或者群组共享",
     "Share with users" : "共享给其他用户",
     "No users or groups" : "无用户或群组",
@@ -96,7 +96,6 @@ OC.L10N.register(
     "Crop contact photo" : "裁剪联系人照片",
     "Upload a new picture" : "上传一张新的图片",
     "Choose from Files" : "从文件中选择",
-    "Get from " : "获取自",
     "Download picture" : "下载图片",
     "Delete picture" : "删除图片",
     "Please select a valid format" : "请选择有效格式",
@@ -178,11 +177,6 @@ OC.L10N.register(
     "Contact not found" : "未找到联系人",
     "Group {group} not found" : "未找到小组 {group} ",
     "Close" : "关闭",
-    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 位联系人已添加到 {name}"],
-    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在添加 {success} 位联系人到 {name}"],
-    "_{count} error_::_{count} errors_" : ["{count} 个错误"],
-    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在导入 %n 个联系人到 {addressbook}"],
-    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 个联系人导入到 {addressbook}"],
     "Import" : "导入",
     "Are you sure you want to import this contact file?" : "您确定您想要导入此联系人文件吗？",
     "Could not copy" : "无法复制",
@@ -194,7 +188,7 @@ OC.L10N.register(
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
     "Organization chart" : "组织图",
-    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "团队是一群人，你可以自己创建，也可以与他们共享数据。它们可以由Nextcloud实例的其它账户或帐户组组成，也可以由通讯簿中的联系人组成，甚至可以由外部人员组成，只需输入他们的电子邮件地址即可。",
+    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "团队是一群人，你可以自己创建，也可以与他们共享数据。它们可以由 Nextcloud 实例的其它账号或账号组组成，也可以由通讯录中的联系人组成，甚至可以由外部人员组成，只需输入他们的电子邮箱地址即可。",
     "User" : "用户",
     "Group" : "小组",
     "Email" : "电子邮件",
@@ -244,7 +238,6 @@ OC.L10N.register(
     "Voice" : "语音",
     "Car" : "车",
     "Work pager" : "工作传呼机",
-    "Manager" : "经理",
     "Social network" : "社交网络",
     "Relationship to you" : "和您的关系",
     "Spouse" : "配偶",
@@ -270,6 +263,8 @@ OC.L10N.register(
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
     "Unable to create team {circleName}" : "无法创建团队 {圈子名称}",
-    "Unable to delete contact" : "无法删除联系人"
+    "Unable to delete contact" : "无法删除联系人",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成员资格必须由一名主持人确认/接受（必须为开放圈子）",
+    "Manager" : "经理"
 },
 "nplurals=1; plural=0;");
